#include "lcd.h"
#include "bitmaps.h"
#include <stdbool.h>
#include <stdint.h>
#include "inc/hw_memmap.h"
#include "driverlib/gpio.h"
#include "driverlib/pin_map.h"
#include "driverlib/ssi.h"
#include "driverlib/sysctl.h"
#include "driverlib/rom.h"  



void LcdWriteCommand(unsigned char command)
{
  
    GPIOPinWrite(GPIO_PORTA_BASE, GPIO_PIN_6, 0x00);    // sce
    GPIOPinWrite(GPIO_PORTA_BASE, GPIO_PIN_7, 0x00);    //  dc
    
    SSIDataPut(SSI0_BASE, command);
    while(SSIBusy(SSI0_BASE));

    GPIOPinWrite(GPIO_PORTA_BASE, GPIO_PIN_7, GPIO_PIN_7);    //  dc
    GPIOPinWrite(GPIO_PORTA_BASE, GPIO_PIN_6, GPIO_PIN_6);    // sce
    
}

void LcdWriteData(unsigned char data)
{
    GPIOPinWrite(GPIO_PORTA_BASE, GPIO_PIN_6, 0x00);          // sce
    GPIOPinWrite(GPIO_PORTA_BASE, GPIO_PIN_7, GPIO_PIN_7);    //  dc
 
    SSIDataPut(SSI0_BASE, data);
    while(SSIBusy(SSI0_BASE));

    GPIOPinWrite(GPIO_PORTA_BASE, GPIO_PIN_7, 0x00);         //  dc
    GPIOPinWrite(GPIO_PORTA_BASE, GPIO_PIN_6, GPIO_PIN_6);   // sce
}


void LcdIoInit()
{
  
   ROM_SysCtlPeripheralEnable(SYSCTL_PERIPH_GPIOB);
    GPIOPinTypeGPIOOutput(GPIO_PORTB_BASE, GPIO_PIN_5);  //  rts
  
    //GPIOPadConfigSet(GPIO_PORTB_BASE, GPIO_PIN_5, GPIO_STRENGTH_4MA, GPIO_PIN_TYPE_STD);
    //GPIODirModeSet(GPIO_PORTB_BASE, GPIO_PIN_5, GPIO_DIR_MODE_OUT);
  
  
    GPIOPinTypeGPIOOutput(GPIO_PORTA_BASE, GPIO_PIN_6);  // sce
    GPIOPinTypeGPIOOutput(GPIO_PORTA_BASE, GPIO_PIN_7);  //  dc
    
    //
    // The SSI0 peripheral must be enabled for use.
    //
    SysCtlPeripheralEnable(SYSCTL_PERIPH_SSI0);

    //
    // For this example SSI0 is used with PortA[5:2].  The actual port and pins
    // used may be different on your part, consult the data sheet for more
    // information.  GPIO port A needs to be enabled so these pins can be used.
    // TODO: change this to whichever GPIO port you are using.
    //
    SysCtlPeripheralEnable(SYSCTL_PERIPH_GPIOA);

    //
    // Configure the pin muxing for SSI0 functions on port A2, A3, A4, and A5.
    // This step is not necessary if your part does not support pin muxing.
    // TODO: change this to select the port/pin you are using.
    //
    GPIOPinConfigure(GPIO_PA2_SSI0CLK);
    GPIOPinConfigure(GPIO_PA3_SSI0FSS);
    GPIOPinConfigure(GPIO_PA4_SSI0RX);
    GPIOPinConfigure(GPIO_PA5_SSI0TX);

    //
    // Configure the GPIO settings for the SSI pins.  This function also gives
    // control of these pins to the SSI hardware.  Consult the data sheet to
    // see which functions are allocated per pin.
    // The pins are assigned as follows:
    //      PA5 - SSI0Tx
    //      PA4 - SSI0Rx
    //      PA3 - SSI0Fss
    //      PA2 - SSI0CLK
    // TODO: change this to select the port/pin you are using.
    //
    GPIOPinTypeSSI(GPIO_PORTA_BASE, GPIO_PIN_5 | GPIO_PIN_4 | GPIO_PIN_3 |
                   GPIO_PIN_2);  
  
}

void LcdSpiInit()
{
    // Configure and enable the SSI port for SPI master mode.  Use SSI0,
    // system clock supply, idle clock level low and active low clock in
    // freescale SPI mode, master mode, 1MHz SSI frequency, and 8-bit data.
    // For SPI mode, you can set the polarity of the SSI clock when the SSI
    // unit is idle.  You can also configure what clock edge you want to
    // capture data on.  Please reference the datasheet for more information on
    // the different SPI modes.
    //
    SSIConfigSetExpClk(SSI0_BASE, SysCtlClockGet(), SSI_FRF_MOTO_MODE_0,
                       SSI_MODE_MASTER, 1000000, 8);

    //
    // Enable the SSI0 module.
    //
    SSIEnable(SSI0_BASE);  
}

void LcdInit()
{
    GPIOPinWrite(GPIO_PORTA_BASE, GPIO_PIN_6, 0x00);  // sce
    GPIOPinWrite(GPIO_PORTB_BASE, GPIO_PIN_5, 0x00);  // res

  
   // Delay to keep printing speed reasonable. About 100 milliseconds.
   //
    ROM_SysCtlDelay(ROM_SysCtlClockGet() / (10 * 3));
 
    GPIOPinWrite(GPIO_PORTB_BASE, GPIO_PIN_5, GPIO_PIN_5);  // res
    GPIOPinWrite(GPIO_PORTA_BASE, GPIO_PIN_6, GPIO_PIN_6);  // sce

    LcdWriteCommand( 0x21 );                    // LCD Extended Commands.
    LcdWriteCommand( 0xC8 );                    // Set LCD Vop (Contrast).
    LcdWriteCommand( 0x06 );                    // Set Temp coefficent.
    LcdWriteCommand( 0x13 );                    // LCD bias mode 1:48.
    LcdWriteCommand( 0x20 );                    // LCD Standard Commands, Horizontal addressing mode.
    LcdWriteCommand( 0x08 );                    // LCD blank
    LcdWriteCommand( 0x0C );                    // LCD in normal mode.
}



void LcdConfigure()
{
    LcdIoInit();
    LcdSpiInit();
    LcdInit();
}

void LcdPozWK ( unsigned char w, unsigned char k )
{
    LcdWriteCommand (0x80 | k);   
    LcdWriteCommand (0x40 | w);   
}

void LcdClear(unsigned char w, unsigned char k, unsigned char wys, unsigned char szer)
{
   unsigned char i, j; 
           
   for(i=0; i<wys; i++)
   {
      LcdPozWK (w + i, k); 
     
      for(j=0; j<szer; j++)
      {
         LcdWriteData(0x00); 
      }
       
   }
   
}


void LcdBitmapa(unsigned char w, unsigned char k, const unsigned char * bitmapa)
{
   unsigned int i;
   unsigned char wysokosc, szerokosc;

   wysokosc   = bitmapa[0];
   szerokosc  = bitmapa[1];
   
   LcdPozWK(w,k);
   
   for(i=2;i<wysokosc*szerokosc + 2; i++)
   {
      if((i-2)%szerokosc == 0 && i!=2)
      {
         w +=1;
         LcdPozWK(w,k);
      }
      LcdWriteData( bitmapa[i]);
   }
}

void LcdByte(unsigned char w, unsigned char k,  unsigned char  byte)
{
   LcdPozWK(w,k);
   LcdWriteData( byte);

}

