#include "system.h"

#include <stdio.h>
#include <stdint.h>
#include <stdbool.h>
#include "lcd.h"
#include "bitmaps.h"
#include "driverlib/sysctl.h"
#include "driverlib/rom.h"
#include "driverlib/uart.h"
#include "utils/uartstdio.h"



float value;

void SystemLcdPrintAB(float result, unsigned char lp)
{
    char tResult[7];
    unsigned char idx;
    
    unsigned char * plus;
    unsigned char * minus;
    unsigned char   lineTmp;
    unsigned char   oPm, oDig, oTmp;
    
    
         value = result;
    bool sMinus = false;
    
    if(value > 125) value = 125;
    if(value < -40) value = -40;
    
    if(lp == 0)
    {
        plus  = (unsigned char *) plusL;
        minus = (unsigned char *) minusL;
        oPm  = 18;
        oDig = 21;
        oTmp = 6;
    }
    else
    {   
        plus  = (unsigned char *) plusP;
        minus = (unsigned char *) minusP;
        oPm   = 42;
        oDig  = 43;
        oTmp  = 77;
    }
    
    
    if(value < 0) 
    {   
        sMinus = true;
        value *= -1;
    }
    
    if(value >= 100)
         sprintf(tResult,"%d", (unsigned int)value);
    else sprintf(tResult,"%2.1f", value);
    
    if(sMinus == true)
      LcdBitmapa(1,oPm,minus);
    else
      LcdBitmapa(1,oPm,plus);
    
    idx    = 0;
    while(tResult[idx] !=0 )
    {
       if(tResult[idx] == '.')
       {
         LcdBitmapa(2,oDig,digitC);
         oDig += 2;
       }
       else
       {
         LcdBitmapa(2,oDig,digits[tResult[idx] - '0']);
         oDig += 6;
       }
       ++idx;
    } 

    value += 40.0;
    lineTmp = (unsigned char)(32 *(float)(value/165));
   
    for(idx =0; idx< 4; idx ++)
      LcdByte(1 + idx, oTmp, 0x00);
    
    for(idx =0; idx< (lineTmp / 8); idx ++)
      LcdByte(4 - idx, oTmp, 0xff);
    
    unsigned char rest = 0x00;
    
    for(idx = 0; idx < (lineTmp%8); idx ++)
        rest += (unsigned char)(0x80 >> (idx - 1));
      
    LcdByte(4 - (lineTmp / 8), oTmp, rest);
    
}

void SystemLcdPrint (float fAmbient,  float fObject)
{
    SystemLcdPrintAB(fAmbient, 0);
    SystemLcdPrintAB(fObject,  1);
}

void SystemUartPrint(float fAmbient,  float fObject)
{
    int_fast32_t i32IntegerPart;
    int_fast32_t i32FractionPart;  
  
    //
    // Convert the floating point ambient temperature  to an integer part
    // and fraction part for easy printing.
    //
    i32IntegerPart = (int32_t)fAmbient;
    i32FractionPart = (int32_t)(fAmbient * 1000.0f);
    i32FractionPart = i32FractionPart - (i32IntegerPart * 1000);
    if(i32FractionPart < 0)
    {
        i32FractionPart *= -1;
    }
    UARTprintf("Ambient: %3d.%03d   ", i32IntegerPart, i32FractionPart);

    //
    // Convert the floating point ambient temperature  to an integer part
    // and fraction part for easy printing.
    //
    i32IntegerPart = (int32_t)fObject;
    i32FractionPart = (int32_t)(fObject * 1000.0f);
    i32FractionPart = i32FractionPart - (i32IntegerPart * 1000);
    if(i32FractionPart < 0)
    {
        i32FractionPart *= -1;
    }
    UARTprintf("Object: %3d.%03d\n", i32IntegerPart, i32FractionPart);
}

void SystemInterruptsEnable()
{
    // Enable interrupts to the processor.
    ROM_IntMasterEnable();
}

void SystemSleepInit()
{
    //
    // Keep only some parts of the systems running while in sleep mode.
    // GPIOE is for the TMP006 data ready interrupt.
    // UART0 is the virtual serial port
    // I2C3 is the I2C interface to the TMP006
    //
    ROM_SysCtlPeripheralClockGating(true);
    ROM_SysCtlPeripheralSleepEnable(SYSCTL_PERIPH_GPIOE);
    ROM_SysCtlPeripheralSleepEnable(SYSCTL_PERIPH_UART0);
    ROM_SysCtlPeripheralSleepEnable(SYSCTL_PERIPH_I2C3);
    
}




